Index: tags/2.1.5/bin/acl.cli.php
===================================================================
--- trunk/bin/acl.cli.php	(revision 365)
+++ tags/2.1.5/bin/acl.cli.php	(revision 377)
@@ -4,5 +4,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/bin/file_importer.php
===================================================================
--- trunk/bin/file_importer.php	(revision 365)
+++ tags/2.1.5/bin/file_importer.php	(revision 377)
@@ -4,5 +4,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/bin/module_maker/_config.inc.php
===================================================================
--- trunk/bin/module_maker/_config.inc.php	(revision 365)
+++ tags/2.1.5/bin/module_maker/_config.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/bin/module_maker/form_template.cli.php
===================================================================
--- trunk/bin/module_maker/form_template.cli.php	(revision 365)
+++ tags/2.1.5/bin/module_maker/form_template.cli.php	(revision 377)
@@ -4,5 +4,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/bin/module_maker/list_template.cli.php
===================================================================
--- trunk/bin/module_maker/list_template.cli.php	(revision 365)
+++ tags/2.1.5/bin/module_maker/list_template.cli.php	(revision 377)
@@ -4,5 +4,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/bin/module_maker/module.cli.php
===================================================================
--- trunk/bin/module_maker/module.cli.php	(revision 365)
+++ tags/2.1.5/bin/module_maker/module.cli.php	(revision 377)
@@ -4,5 +4,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/bin/module_maker/skel/admin.php
===================================================================
--- trunk/bin/module_maker/skel/admin.php	(revision 365)
+++ tags/2.1.5/bin/module_maker/skel/admin.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/bin/module_maker/skel/public.php
===================================================================
--- trunk/bin/module_maker/skel/public.php	(revision 365)
+++ tags/2.1.5/bin/module_maker/skel/public.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/bin/module_maker/sql.cli.php
===================================================================
--- trunk/bin/module_maker/sql.cli.php	(revision 365)
+++ tags/2.1.5/bin/module_maker/sql.cli.php	(revision 377)
@@ -4,5 +4,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/bin/module_maker/validation.cli.php
===================================================================
--- trunk/bin/module_maker/validation.cli.php	(revision 365)
+++ tags/2.1.5/bin/module_maker/validation.cli.php	(revision 377)
@@ -4,5 +4,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/docs/examples/_config.inc.php
===================================================================
--- trunk/docs/examples/_config.inc.php	(revision 365)
+++ tags/2.1.5/docs/examples/_config.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/docs/examples/contact_form/contact.php
===================================================================
--- trunk/docs/examples/contact_form/contact.php	(revision 365)
+++ tags/2.1.5/docs/examples/contact_form/contact.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/docs/examples/db_auth.inc.php
===================================================================
--- trunk/docs/examples/db_auth.inc.php	(revision 365)
+++ tags/2.1.5/docs/examples/db_auth.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/docs/examples/example.cli.php
===================================================================
--- trunk/docs/examples/example.cli.php	(revision 365)
+++ tags/2.1.5/docs/examples/example.cli.php	(revision 377)
@@ -4,5 +4,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/docs/examples/script_template.php
===================================================================
--- trunk/docs/examples/script_template.php	(revision 365)
+++ tags/2.1.5/docs/examples/script_template.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/docs/readme.txt
===================================================================
--- trunk/docs/readme.txt	(revision 365)
+++ tags/2.1.5/docs/readme.txt	(revision 377)
@@ -1,5 +1,5 @@
 The Strangecode Codebase - a general application development framework for PHP
 For details visit the project site: <http://trac.strangecode.com/codebase/>
-Copyright 2001-2009 Strangecode Internet Consultancy
+Copyright 2001-2010 Strangecode, LLC
 
 
@@ -23,8 +23,9 @@
 
 hello@strangecode.com
-+1 530 554 9555
++1 530 636 2633
 
-Strangecode Internet Consultancy
+Strangecode, LLC
 PO Box 1842
 Chico CA 95927
 United States
+
Index: tags/2.1.5/docs/version.txt
===================================================================
--- trunk/docs/version.txt	(revision 365)
+++ tags/2.1.5/docs/version.txt	(revision 377)
@@ -1,1 +1,1 @@
-2.1.4dev
+2.1.5
Index: tags/2.1.5/lib/ACL.inc.php
===================================================================
--- trunk/lib/ACL.inc.php	(revision 365)
+++ tags/2.1.5/lib/ACL.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/App.inc.php
===================================================================
--- trunk/lib/App.inc.php	(revision 365)
+++ tags/2.1.5/lib/App.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
@@ -314,4 +314,14 @@
         if (true === $this->getParam('enable_session')) {
 
+            // Session parameters.
+            ini_set('session.gc_probability', 1);
+            ini_set('session.gc_divisor', 1000);
+            ini_set('session.gc_maxlifetime', 43200); // 12 hours
+            ini_set('session.use_cookies', $this->getParam('session_use_cookies'));
+            ini_set('session.use_trans_sid', false);
+            ini_set('session.entropy_file', '/dev/urandom');
+            ini_set('session.entropy_length', '512');
+            session_name($this->getParam('session_name'));
+
             if (true === $this->getParam('enable_db_session_handler') && true === $this->getParam('enable_db')) {
                 // Database session handling.
@@ -322,11 +332,4 @@
                 ));
             }
-
-            // Session parameters.
-            ini_set('session.use_cookies', $this->getParam('session_use_cookies'));
-            ini_set('session.use_trans_sid', false);
-            ini_set('session.entropy_file', '/dev/urandom');
-            ini_set('session.entropy_length', '512');
-            session_name($this->getParam('session_name'));
 
             // Start the session.
Index: tags/2.1.5/lib/Auth_File.inc.php
===================================================================
--- trunk/lib/Auth_File.inc.php	(revision 365)
+++ tags/2.1.5/lib/Auth_File.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/AuthorizeNet.inc.php
===================================================================
--- trunk/lib/AuthorizeNet.inc.php	(revision 365)
+++ tags/2.1.5/lib/AuthorizeNet.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/CSS.inc.php
===================================================================
--- trunk/lib/CSS.inc.php	(revision 365)
+++ tags/2.1.5/lib/CSS.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/Cache.inc.php
===================================================================
--- trunk/lib/Cache.inc.php	(revision 365)
+++ tags/2.1.5/lib/Cache.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/Captcha.inc.php
===================================================================
--- trunk/lib/Captcha.inc.php	(revision 365)
+++ tags/2.1.5/lib/Captcha.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/Cart.inc.php
===================================================================
--- trunk/lib/Cart.inc.php	(revision 365)
+++ tags/2.1.5/lib/Cart.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/Currency.inc.php
===================================================================
--- trunk/lib/Currency.inc.php	(revision 365)
+++ tags/2.1.5/lib/Currency.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/DB.inc.php
===================================================================
--- trunk/lib/DB.inc.php	(revision 365)
+++ tags/2.1.5/lib/DB.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/DBSessionHandler.inc.php
===================================================================
--- trunk/lib/DBSessionHandler.inc.php	(revision 365)
+++ tags/2.1.5/lib/DBSessionHandler.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
@@ -73,5 +73,4 @@
                 $this->initDB();
 
-                ini_set('session.save_handler', 'user');
                 session_set_save_handler(
                     array(&$this, 'dbSessionOpen'),
@@ -82,4 +81,5 @@
                     array(&$this, 'dbSessionGarbage')
                 );
+                register_shutdown_function('session_write_close');
             }
         }
@@ -126,5 +126,5 @@
 
     function dbSessionClose()
-    {
+    {        
         return true;
     }
@@ -161,7 +161,7 @@
     }
 
-    function dbSessionGarbage($max_lifetime=4000)
+    function dbSessionGarbage($max_lifetime=72000)
     {
-        // Delete old values from the session table
+        // Delete old values from the session table.
         $qid = $this->db->query("DELETE FROM " . $this->db->escapeString($this->_params['db_table']) . " WHERE UNIX_TIMESTAMP(last_access) < " . (time() - $max_lifetime));
 
Index: tags/2.1.5/lib/Email.inc.php
===================================================================
--- trunk/lib/Email.inc.php	(revision 365)
+++ tags/2.1.5/lib/Email.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/FormValidator.inc.php
===================================================================
--- trunk/lib/FormValidator.inc.php	(revision 365)
+++ tags/2.1.5/lib/FormValidator.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
@@ -373,9 +373,8 @@
      * pattern.
      *
-     * @param  string $form_name the name of the incoming form variable
-     * @param  int    $regex     perl regex that the string must match
-     * @param  bool   $valid_on_match       set to false to be valid if match, or true
-     *                           to be valid on no match
-     * @param  string $msg       the message to display on error
+     * @param  string $form_name        The name of the incoming form variable
+     * @param  int    $regex            Perl regex that the string must match
+     * @param  bool   $valid_on_match   Set to true to be valid if match, or false to be valid if the match fails.
+     * @param  string $msg              The message to display on error
      *
      * @return bool   true if value passes regex test
Index: tags/2.1.5/lib/Google_API.inc.php
===================================================================
--- trunk/lib/Google_API.inc.php	(revision 365)
+++ tags/2.1.5/lib/Google_API.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/Hierarchy.inc.php
===================================================================
--- trunk/lib/Hierarchy.inc.php	(revision 365)
+++ tags/2.1.5/lib/Hierarchy.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/Image.inc.php
===================================================================
--- trunk/lib/Image.inc.php	(revision 365)
+++ tags/2.1.5/lib/Image.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/ImageThumb.inc.php
===================================================================
--- trunk/lib/ImageThumb.inc.php	(revision 365)
+++ tags/2.1.5/lib/ImageThumb.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/Lock.inc.php
===================================================================
--- trunk/lib/Lock.inc.php	(revision 365)
+++ tags/2.1.5/lib/Lock.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/MCVE.inc.php
===================================================================
--- trunk/lib/MCVE.inc.php	(revision 365)
+++ tags/2.1.5/lib/MCVE.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/Navigation.inc.php
===================================================================
--- trunk/lib/Navigation.inc.php	(revision 365)
+++ tags/2.1.5/lib/Navigation.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/PEdit.inc.php
===================================================================
--- trunk/lib/PEdit.inc.php	(revision 365)
+++ tags/2.1.5/lib/PEdit.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/PageNumbers.inc.php
===================================================================
--- trunk/lib/PageNumbers.inc.php	(revision 365)
+++ tags/2.1.5/lib/PageNumbers.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/PageSequence.inc.php
===================================================================
--- trunk/lib/PageSequence.inc.php	(revision 365)
+++ tags/2.1.5/lib/PageSequence.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/PayPal.inc.php
===================================================================
--- trunk/lib/PayPal.inc.php	(revision 365)
+++ tags/2.1.5/lib/PayPal.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/Prefs.inc.php
===================================================================
--- trunk/lib/Prefs.inc.php	(revision 365)
+++ tags/2.1.5/lib/Prefs.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/ScriptTimer.inc.php
===================================================================
--- trunk/lib/ScriptTimer.inc.php	(revision 365)
+++ tags/2.1.5/lib/ScriptTimer.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/SortOrder.inc.php
===================================================================
--- trunk/lib/SortOrder.inc.php	(revision 365)
+++ tags/2.1.5/lib/SortOrder.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/SpellCheck.inc.php
===================================================================
--- trunk/lib/SpellCheck.inc.php	(revision 365)
+++ tags/2.1.5/lib/SpellCheck.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/TemplateGlue.inc.php
===================================================================
--- trunk/lib/TemplateGlue.inc.php	(revision 365)
+++ tags/2.1.5/lib/TemplateGlue.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/Upload.inc.php
===================================================================
--- trunk/lib/Upload.inc.php	(revision 365)
+++ tags/2.1.5/lib/Upload.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/lib/Utilities.inc.php
===================================================================
--- trunk/lib/Utilities.inc.php	(revision 365)
+++ tags/2.1.5/lib/Utilities.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
@@ -895,5 +895,5 @@
             return true;
         } else {
-            $app->logMsg(sprintf('Mailman add member failed for list: %s, user: %s, with message: %s', $list, $email, $stdout), LOG_WARNING, __FILE__, __LINE__);
+            $app->logMsg(sprintf('Mailman add member failed for list: %s, user: %s, with message: %s', $list, $email, getDump($stdout)), LOG_WARNING, __FILE__, __LINE__);
             return false;
         }
Index: tags/2.1.5/lib/Validator.inc.php
===================================================================
--- trunk/lib/Validator.inc.php	(revision 365)
+++ tags/2.1.5/lib/Validator.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
@@ -135,6 +135,5 @@
      * @param  string $val The input data to validate.
      * @param  int    $regex            PREG that the string must match
-     * @param  bool   $valid_on_match   Set to false to be valid if match, or true
-     *                                  to be valid on no match
+     * @param  bool   $valid_on_match   Set to true to be valid if match, or false to be valid if the match fails.
      * @return bool   true if value passes regex test
      */
Index: tags/2.1.5/lib/Version.inc.php
===================================================================
--- trunk/lib/Version.inc.php	(revision 365)
+++ tags/2.1.5/lib/Version.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/services/admins.php
===================================================================
--- trunk/services/admins.php	(revision 365)
+++ tags/2.1.5/services/admins.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/services/css.php
===================================================================
--- trunk/services/css.php	(revision 365)
+++ tags/2.1.5/services/css.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/services/lock.php
===================================================================
--- trunk/services/lock.php	(revision 365)
+++ tags/2.1.5/services/lock.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/services/login.php
===================================================================
--- trunk/services/login.php	(revision 365)
+++ tags/2.1.5/services/login.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
@@ -44,5 +44,5 @@
     } else {
         $app->raiseMsg(_("Login failed, please try again."), MSG_NOTICE, __FILE__, __LINE__);
-        $app->logMsg(sprintf('User %s failed login using (MD5ed) password: %s', $frm['username'], md5($frm['password'])), LOG_NOTICE, __FILE__, __LINE__);
+        $app->logMsg(sprintf('User %s failed login (encrypted password: %s)', $frm['username'], $auth->encryptPassword($frm['password'])), LOG_NOTICE, __FILE__, __LINE__);
     }
 }
Index: tags/2.1.5/services/logout.php
===================================================================
--- trunk/services/logout.php	(revision 365)
+++ tags/2.1.5/services/logout.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/services/logs.php
===================================================================
--- trunk/services/logs.php	(revision 365)
+++ tags/2.1.5/services/logs.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/services/password.php
===================================================================
--- trunk/services/password.php	(revision 365)
+++ tags/2.1.5/services/password.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/services/phpinfo.php
===================================================================
--- trunk/services/phpinfo.php	(revision 365)
+++ tags/2.1.5/services/phpinfo.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/services/reset_password.php
===================================================================
--- trunk/services/reset_password.php	(revision 365)
+++ tags/2.1.5/services/reset_password.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/services/versions.php
===================================================================
--- trunk/services/versions.php	(revision 365)
+++ tags/2.1.5/services/versions.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/AppTest.php
===================================================================
--- trunk/tests/AppTest.php	(revision 365)
+++ tags/2.1.5/tests/AppTest.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/Auth_FileTest.php
===================================================================
--- trunk/tests/Auth_FileTest.php	(revision 365)
+++ tags/2.1.5/tests/Auth_FileTest.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/Auth_SQLTest.php
===================================================================
--- trunk/tests/Auth_SQLTest.php	(revision 365)
+++ tags/2.1.5/tests/Auth_SQLTest.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/AuthorizeNetTest.php
===================================================================
--- trunk/tests/AuthorizeNetTest.php	(revision 365)
+++ tags/2.1.5/tests/AuthorizeNetTest.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/CSSTest.php
===================================================================
--- trunk/tests/CSSTest.php	(revision 365)
+++ tags/2.1.5/tests/CSSTest.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/CacheTest.php
===================================================================
--- trunk/tests/CacheTest.php	(revision 365)
+++ tags/2.1.5/tests/CacheTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/DBSessionHandlerTest.php
===================================================================
--- trunk/tests/DBSessionHandlerTest.php	(revision 365)
+++ tags/2.1.5/tests/DBSessionHandlerTest.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/EmailTest.php
===================================================================
--- trunk/tests/EmailTest.php	(revision 365)
+++ tags/2.1.5/tests/EmailTest.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/FormValidatorTest.php
===================================================================
--- trunk/tests/FormValidatorTest.php	(revision 365)
+++ tags/2.1.5/tests/FormValidatorTest.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/Google_APITest.php
===================================================================
--- trunk/tests/Google_APITest.php	(revision 365)
+++ tags/2.1.5/tests/Google_APITest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/HierarchyTest.php
===================================================================
--- trunk/tests/HierarchyTest.php	(revision 365)
+++ tags/2.1.5/tests/HierarchyTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/ImageThumbTest.php
===================================================================
--- trunk/tests/ImageThumbTest.php	(revision 365)
+++ tags/2.1.5/tests/ImageThumbTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/LockTest.php
===================================================================
--- trunk/tests/LockTest.php	(revision 365)
+++ tags/2.1.5/tests/LockTest.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/MCVETest.php
===================================================================
--- trunk/tests/MCVETest.php	(revision 365)
+++ tags/2.1.5/tests/MCVETest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/NavTest.php
===================================================================
--- trunk/tests/NavTest.php	(revision 365)
+++ tags/2.1.5/tests/NavTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/PEditTest.php
===================================================================
--- trunk/tests/PEditTest.php	(revision 365)
+++ tags/2.1.5/tests/PEditTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/PageNumbersTest.php
===================================================================
--- trunk/tests/PageNumbersTest.php	(revision 365)
+++ tags/2.1.5/tests/PageNumbersTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/PageSequenceTest.php
===================================================================
--- trunk/tests/PageSequenceTest.php	(revision 365)
+++ tags/2.1.5/tests/PageSequenceTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/PayPalTest.php
===================================================================
--- trunk/tests/PayPalTest.php	(revision 365)
+++ tags/2.1.5/tests/PayPalTest.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/PrefsTest.php
===================================================================
--- trunk/tests/PrefsTest.php	(revision 365)
+++ tags/2.1.5/tests/PrefsTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/ScriptTimerTest.php
===================================================================
--- trunk/tests/ScriptTimerTest.php	(revision 365)
+++ tags/2.1.5/tests/ScriptTimerTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/SortOrderTest.php
===================================================================
--- trunk/tests/SortOrderTest.php	(revision 365)
+++ tags/2.1.5/tests/SortOrderTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/SpellCheckTest.php
===================================================================
--- trunk/tests/SpellCheckTest.php	(revision 365)
+++ tags/2.1.5/tests/SpellCheckTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/TemplateGlueTest.php
===================================================================
--- trunk/tests/TemplateGlueTest.php	(revision 365)
+++ tags/2.1.5/tests/TemplateGlueTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/UploadTest.php
===================================================================
--- trunk/tests/UploadTest.php	(revision 365)
+++ tags/2.1.5/tests/UploadTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/UtilitiesTest.php
===================================================================
--- trunk/tests/UtilitiesTest.php	(revision 365)
+++ tags/2.1.5/tests/UtilitiesTest.php	(revision 377)
@@ -6,5 +6,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/VersionTest.php
===================================================================
--- trunk/tests/VersionTest.php	(revision 365)
+++ tags/2.1.5/tests/VersionTest.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/_config.inc.php
===================================================================
--- trunk/tests/_config.inc.php	(revision 365)
+++ tags/2.1.5/tests/_config.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
Index: tags/2.1.5/tests/_skel.php
===================================================================
--- trunk/tests/_skel.php	(revision 365)
+++ tags/2.1.5/tests/_skel.php	(revision 377)
@@ -4,5 +4,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.

Index: tags/2.1.5/lib/Auth_SQL.inc.php
===================================================================
--- trunk/lib/Auth_SQL.inc.php	(revision 365)
+++ tags/2.1.5/lib/Auth_SQL.inc.php	(revision 377)
@@ -3,5 +3,5 @@
  * The Strangecode Codebase - a general application development framework for PHP
  * For details visit the project site: <http://trac.strangecode.com/codebase/>
- * Copyright 2001-2009 Strangecode Internet Consultancy
+ * Copyright 2001-2010 Strangecode, LLC
  * 
  * This file is part of The Strangecode Codebase.
@@ -251,4 +251,10 @@
     function setParam($params)
     {
+        if (isset($params['match_remote_ip_exempt_usernames'])) {
+            $params['match_remote_ip_exempt_usernames'] = array_map('strtolower', $params['match_remote_ip_exempt_usernames']);
+        }
+        if (isset($params['login_abuse_exempt_usernames'])) {
+            $params['login_abuse_exempt_usernames'] = array_map('strtolower', $params['login_abuse_exempt_usernames']);
+        }
         if (isset($params) && is_array($params)) {
             // Merge new parameters with old overriding only those passed.
@@ -376,8 +382,8 @@
             // Don't return password value.
             unset($user_data['userpass']);
-            $app->logMsg(sprintf('Authentication successful for user %s (%s)', $user_data['user_id'], $username), LOG_INFO, __FILE__, __LINE__);
+            $app->logMsg(sprintf('Authentication successful for user_id %s (%s)', $user_data['user_id'], $username), LOG_INFO, __FILE__, __LINE__);
             return $user_data;
         } else {
-            $app->logMsg(sprintf('Authentication failed for user %s (encrypted attempted password: %s)', $username, $this->encryptPassword($password)), LOG_NOTICE, __FILE__, __LINE__);
+            $app->logMsg(sprintf('Authentication failed for username %s (encrypted attempted password: %s)', $username, $this->encryptPassword($password)), LOG_NOTICE, __FILE__, __LINE__);
             return false;
         }
@@ -404,4 +410,9 @@
             // No login: failed authentication!
             return false;
+        }
+        
+        // Convert 'priv' to 'user_type' nomenclature.
+        if (isset($user_data['priv'])) {
+            $user_data['user_type'] = $user_data['priv'];
         }
 
@@ -425,5 +436,5 @@
             if (!empty($user_data['blocked'])) {
 
-                $app->logMsg(sprintf('User %s (%s) login failed due to blocked account: %s', $this->get('user_id'), $this->get('username'), $this->get('blocked_reason')), LOG_NOTICE, __FILE__, __LINE__);
+                $app->logMsg(sprintf('User_id %s (%s) login failed due to blocked account: %s', $this->get('user_id'), $this->get('username'), $this->get('blocked_reason')), LOG_NOTICE, __FILE__, __LINE__);
 
                 switch ($user_data['blocked_reason']) {
@@ -460,10 +471,10 @@
                     $this->resetPassword(null, _("This is a security precaution. We have detected this account has been accessed from multiple computers simultaneously. It is against policy to share login information with others. If further account abuse is detected this account will be blocked."));
                     $app->raiseMsg(_("Your password has been reset as a security precaution. Please check your email for more information."), MSG_NOTICE, __FILE__, __LINE__);
-                    $app->logMsg(sprintf('Account abuse detected for user %s (%s) from IP %s', $this->get('user_id'), $this->get('username'), $this->get('remote_ip')), LOG_WARNING, __FILE__, __LINE__);
+                    $app->logMsg(sprintf('Account abuse detected for user_id %s (%s) from IP %s', $this->get('user_id'), $this->get('username'), $this->get('remote_ip')), LOG_WARNING, __FILE__, __LINE__);
                 } else {
                     // Block the account with the reason of account abuse.
                     $this->blockAccount(null, 'account abuse');
                     $app->raiseMsg(_("Your account has been blocked as a security precaution. Please contact us for more information."), MSG_NOTICE, __FILE__, __LINE__);
-                    $app->logMsg(sprintf('Account blocked for user %s (%s) from IP %s', $this->get('user_id'), $this->get('username'), $this->get('remote_ip')), LOG_ALERT, __FILE__, __LINE__);
+                    $app->logMsg(sprintf('Account blocked for user_id %s (%s) from IP %s', $this->get('user_id'), $this->get('username'), $this->get('remote_ip')), LOG_ALERT, __FILE__, __LINE__);
                 }
                 // Increment user's warning level.
@@ -518,5 +529,5 @@
 		$app =& App::getInstance();
     	$db =& DB::getInstance();
-	
+
         $this->initDB();
 
@@ -529,9 +540,12 @@
                 AND DATE_ADD(last_access_datetime, INTERVAL '" . $this->_params['idle_timeout'] . "' SECOND) > NOW()
             ");
-            return (mysql_num_rows($qid) > 0);
+            $login_status = (mysql_num_rows($qid) > 0);
+            $app->logMsg(sprintf('Returning %s login status for user_id %s', ($login_status ? 'true' : 'false'), $user_id), LOG_DEBUG, __FILE__, __LINE__);
+            return $login_status;
         }
 
         // User login test need only be run once per script execution. We cache the result in the session.
         if ($this->_authentication_tested && isset($_SESSION['_auth_sql'][$this->_ns]['authenticated'])) {
+            $app->logMsg(sprintf('Returning cached authentication status: %s', ($_SESSION['_auth_sql'][$this->_ns]['authenticated'] ? 'true' : 'false')), LOG_DEBUG, __FILE__, __LINE__);
             return $_SESSION['_auth_sql'][$this->_ns]['authenticated'];
         }
@@ -540,15 +554,16 @@
         $this->_authentication_tested = true;
 
         // Some users will access from networks with a changing IP number (i.e. behind a proxy server). These users must be allowed entry by adding their IP to the list of trusted_networks.
         if ($trusted_net = ipInRange(getRemoteAddr(), $this->_params['trusted_networks'])) {
             $user_in_trusted_network = true;
-            $app->logMsg(sprintf('User %s accessing from trusted network %s',
-                ($this->get('user_id') ? ' ' . $this->get('user_id') . ' (' .  $this->get('username') . ')' : ''),
+            $app->logMsg(sprintf('User_id %s accessing from trusted network %s',
+                ($this->get('user_id') ? $this->get('user_id') . ' (' .  $this->get('username') . ')' : 'unknown'),
                 $trusted_net
             ), LOG_DEBUG, __FILE__, __LINE__);
         } else if (preg_match('/proxy.aol.com$/i', getRemoteAddr(true))) {
             $user_in_trusted_network = true;
-            $app->logMsg(sprintf('User %s accessing from trusted network proxy.aol.com',
-                ($this->get('user_id') ? ' ' . $this->get('user_id') . ' (' .  $this->get('username') . ')' : '')
+            $app->logMsg(sprintf('User_id %s accessing from trusted network proxy.aol.com',
+                ($this->get('user_id') ? $this->get('user_id') . ' (' .  $this->get('username') . ')' : 'unknown')
             ), LOG_DEBUG, __FILE__, __LINE__);
         } else {
@@ -560,6 +575,6 @@
             $remote_ip_is_matched = (isset($_SESSION['_auth_sql'][$this->_ns]['remote_ip']) && $_SESSION['_auth_sql'][$this->_ns]['remote_ip'] == getRemoteAddr()) || $user_in_trusted_network;
         } else {
-            $app->logMsg(sprintf('User %s exempt from remote_ip match (comparing %s == %s)', 
-                ($this->get('user_id') ? ' ' . $this->get('user_id') . ' (' .  $this->get('username') . ')' : ''),
+            $app->logMsg(sprintf('User_id %s exempt from remote_ip match (comparing %s == %s)', 
+                ($this->get('user_id') ? $this->get('user_id') . ' (' .  $this->get('username') . ')' : 'unknown'),
                 $_SESSION['_auth_sql'][$this->_ns]['remote_ip'],
                 getRemoteAddr()
@@ -571,6 +586,9 @@
         if (isset($_SESSION['_auth_sql'][$this->_ns]['authenticated']) 
             && true === $_SESSION['_auth_sql'][$this->_ns]['authenticated']
+            && isset($_SESSION['_auth_sql'][$this->_ns]['username'])
             && !empty($_SESSION['_auth_sql'][$this->_ns]['username'])
+            && isset($_SESSION['_auth_sql'][$this->_ns]['login_datetime'])
             && strtotime($_SESSION['_auth_sql'][$this->_ns]['login_datetime']) > time() - $this->_params['login_timeout']
+            && isset($_SESSION['_auth_sql'][$this->_ns]['last_access_datetime'])
             && strtotime($_SESSION['_auth_sql'][$this->_ns]['last_access_datetime']) > time() - $this->_params['idle_timeout']
             && $remote_ip_is_matched
@@ -590,5 +608,5 @@
                 return true;
             } else {
-                $app->logMsg(sprintf('User update failed. Record not found for user %s (%s).', $this->get('user_id'), $this->get('username')), LOG_NOTICE, __FILE__, __LINE__);
+                $app->logMsg(sprintf('Session update failed; record not found for user_id %s (%s).', $this->get('user_id'), $this->get('username')), LOG_NOTICE, __FILE__, __LINE__);
             }
         } else if (isset($_SESSION['_auth_sql'][$this->_ns]['authenticated']) && true === $_SESSION['_auth_sql'][$this->_ns]['authenticated']) {
@@ -605,11 +623,15 @@
             }
             if (strtotime($_SESSION['_auth_sql'][$this->_ns]['login_datetime']) <= time() - $this->_params['login_timeout']) {
-                $expire_reasons[] = 'login_timeout expired';
+                $expire_reasons[] = sprintf('login_timeout expired (%s older than %s seconds ago)', $_SESSION['_auth_sql'][$this->_ns]['login_datetime'], $this->_params['login_timeout']);
             }
             if (strtotime($_SESSION['_auth_sql'][$this->_ns]['last_access_datetime']) <= time() - $this->_params['idle_timeout']) {
-                $expire_reasons[] = 'idle_timeout expired';
-            }
-            if ($_SESSION['_auth_sql'][$this->_ns]['remote_ip'] != getRemoteAddr() && !$user_in_trusted_network) {
-                if ($this->getParam('match_remote_ip') && !$this->get('match_remote_ip_exempt')) {
+                $expire_reasons[] = sprintf('idle_timeout expired (%s older than %s seconds ago)', $_SESSION['_auth_sql'][$this->_ns]['last_access_datetime'], $this->_params['idle_timeout']);
+            }
+            if ($_SESSION['_auth_sql'][$this->_ns]['remote_ip'] != getRemoteAddr()) {
+                if ($this->getParam('match_remote_ip') && !$this->get('match_remote_ip_exempt') && !$user_in_trusted_network) {
+                    // There are three cases when a remote IP match will be the cause of a session termination:
+                    //   1. match_remote_ip config is enabled
+                    //   2. user is not match_remote_ip_exempt (set in the user_data, or in the match_remote_ip_exempt_usernames list)
+                    //   3. the user is connecting from a trusted network (their IP is listed in the trusted_networks or from *.proxy.aol.com)
                     $expire_reasons[] = sprintf('remote_ip not matched (%s != %s)', $_SESSION['_auth_sql'][$this->_ns]['remote_ip'], getRemoteAddr());
                 } else {
@@ -617,5 +639,7 @@
                 }
             }
-            $app->logMsg(sprintf('User %s (%s) session expired: %s', $this->get('user_id'), $this->get('username'), join(', ', $expire_reasons)), LOG_INFO, __FILE__, __LINE__);
+            $app->logMsg(sprintf('User_id %s (%s) session expired: %s', $this->get('user_id'), $this->get('username'), join(', ', $expire_reasons)), LOG_INFO, __FILE__, __LINE__);
+        } else {
+            $app->logMsg(sprintf('Session not authenticated: %s', getDump($_SESSION['_auth_sql'][$this->_ns])), LOG_DEBUG, __FILE__, __LINE__);
         }
 
@@ -854,4 +878,5 @@
             return $hash;
             break;
+
         default :
             $app->logMsg(sprintf('Authentication encrypt type specified is unrecognized: %s', $this->_params['encryption_type']), LOG_NOTICE, __FILE__, __LINE__);
@@ -900,5 +925,5 @@
         
         if (mysql_affected_rows($db->getDBH()) != 1) {
-            $app->logMsg(sprintf('Failed to update password for user %s', $user_id), LOG_WARNING, __FILE__, __LINE__);
+            $app->logMsg(sprintf('Failed to update password for user_id %s', $user_id), LOG_WARNING, __FILE__, __LINE__);
             return false;
         }
@@ -930,5 +955,5 @@
         ");
         if (!$user_data = mysql_fetch_assoc($qid)) {
-            $app->logMsg(sprintf('Reset password failed. User %s not found.', $user_id), LOG_NOTICE, __FILE__, __LINE__);
+            $app->logMsg(sprintf('Reset password failed. User_id %s not found.', $user_id), LOG_NOTICE, __FILE__, __LINE__);
             return false;
         }
@@ -942,5 +967,5 @@
         // Make sure user has an email on record before continuing.
         if (!isset($user_data['email']) || '' == trim($user_data['email'])) {
-            $app->logMsg(sprintf('Password reset but notification failed, no email address for user %s (%s).', $user_data[$this->_params['db_primary_key']], $user_data[$this->_params['db_username_column']]), LOG_NOTICE, __FILE__, __LINE__);
+            $app->logMsg(sprintf('Password reset but notification failed, no email address for user_id %s (%s).', $user_data[$this->_params['db_primary_key']], $user_data[$this->_params['db_username_column']]), LOG_NOTICE, __FILE__, __LINE__);
         } else {
             // Send the new password in an email.
@@ -540,15 +554,16 @@
         $this->_authentication_tested = true;
 
-        // Some users will access from networks with a changing IP number (i.e. behind a proxy server). These users must be allowed entry by adding their IP to the list of trusted_networks.
+        // Some users will access from networks with a changing IP number (i.e. behind a proxy server). 
+        // These users must be allowed entry by adding their IP to the list of trusted_networks, or their usernames to the list of match_remote_ip_exempt_usernames.
         if ($trusted_net = ipInRange(getRemoteAddr(), $this->_params['trusted_networks'])) {
             $user_in_trusted_network = true;